@@ -13,8 +13,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef GCONF_GCONF_ERROR_H
@@ -22,16 +22,14 @@
 
 #include <glib.h>
 
-#ifdef __cplusplus
-extern "C" {
-#endif /* __cplusplus */
+G_BEGIN_DECLS
 
 #define GCONF_ERROR gconf_error_quark ()
 
 /* Error Numbers */
 
 /* Sync with ConfigErrorType in GConf.idl, and some switch statements in the code */
-typedef enum { /*< prefix=GCONF_ERROR >*/
+typedef enum {
   GCONF_ERROR_SUCCESS = 0,
   GCONF_ERROR_FAILED = 1,        /* Something didn't work, don't know why, probably unrecoverable
                                     so there's no point having a more specific errno */
@@ -56,9 +54,7 @@ typedef enum { /*< prefix=GCONF_ERROR >*/
 
 GQuark gconf_error_quark (void);
 
-#ifdef __cplusplus
-}
-#endif /* __cplusplus */
+G_END_DECLS
 
 #endif
 
